==> powertool-0.1.0.tar.gz: powertool-0.1.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=6.0',
    # TODO: put package requirements here
]

test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='powertool',
    version='0.1.0',
    description="Python utility to wake up(wol) and suspend Linux machines remotely",
    long_description=readme + '\n\n' + history,
    author="Raghu Rajagopalan",
    author_email='raghu.nospam@gmail.com',
    url='https://github.com/raghur/powertool',
    packages=[
        'powertool',
    ],
    package_dir={'powertool':
                 'powertool'},
    entry_points={
        'console_scripts': [
            'powertool=powertool.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license="MIT license",
    zip_safe=False,
    keywords='powertool',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements
)

==> powertool-0.2.0.tar.gz: powertool-0.2.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=6.0',
    'coloredlogs',
    'wakeonlan'
    # TODO: put package requirements here
]

test_requirements = [
    # TODO: put package test requirements here
    'pytest',
    'mock',
    'coverage',
    'tox',
    'flake8'
]

setup(
    name='powertool',
    version='0.2.0',
    description="Python utility to wake up(wol) and suspend "
    "Linux machines remotely",
    long_description=readme + '\n\n' + history,
    author="Raghu Rajagopalan",
    author_email='raghu.nospam@gmail.com',
    url='https://github.com/raghur/powertool',
    packages=[
        'powertool',
    ],
    package_dir={'powertool':
                 'powertool'},
    entry_points={
        'console_scripts': [
            'powertool=powertool.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license="MIT license",
    zip_safe=False,
    keywords='powertool',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements
)
